# Google Search Origin

Google Search Origin is library for searching via requests (like on Google).
Google Search Origin uses requests and BeautifulSoup4.
The main functionnality is to scrap google to obtain links.

## Installation

To install, run the following command:

`python3 -m pip install google-search-origin`

or

`pip3 install google-search-origin`

## Usage

## Parameters

## Unittests